@@ -145,6 +145,7 @@ has file_header => (is => 'lazy', isa => Object);
 has cover => (is => 'lazy', isa => Str);
 has coverwidth => (is => 'lazy', isa => Str);
 has nocoverpage => (is => 'lazy', isa => Bool);
+has notoc => (is => 'lazy', isa => Bool);
 has fonts => (is => 'ro', isa => InstanceOf['Text::Amuse::Compile::Fonts::Selected']);
 has epub_embed_fonts => (is => 'ro', isa => Bool, default => sub { 1 });
 
@@ -198,7 +199,7 @@ sub _build_full_options {
     # print "Building full options\n" if DEBUG;
     my %options = %{ $self->options };
     # these values are picked from the file, if not provided by the compiler
-    foreach my $override (qw/cover coverwidth nocoverpage/) {
+    foreach my $override (qw/cover coverwidth nocoverpage notoc/) {
         $options{$override} = $self->$override;
     }
     return \%options;
@@ -240,7 +241,6 @@ sub _build_coverwidth {
 
 sub _build_nocoverpage {
     my $self = shift;
-    # here the file takes precedence, dunno why.
     if ($self->file_header->nocoverpage) {
         return 1;
     }
@@ -252,6 +252,20 @@ sub _build_nocoverpage {
     }
 }
 
+sub _build_notoc {
+    my $self = shift;
+    if ($self->file_header->notoc) {
+        return 1;
+    }
+    elsif ($self->options->{notoc}) {
+        return 1;
+    }
+    else {
+        return 0;
+    }
+}
+
+
 sub _escape_options_hashref {
     my ($self, $format, $ref) = @_;
     die "Wrong usage of internal method" unless $format && $ref;
@@ -1119,13 +1133,16 @@ sub _prepare_tex_tokens {
     }
 
     # no cover page
-    unless ($doc->wants_toc) {
+    # here we used to have a conditional ->wants_toc, removed.
+    # Instead, the template should say \let\chapter\section or
+    # \let\chapter\part
+
         if ($self->nocoverpage) {
             $parsed{nocoverpage} = 1;
             $parsed{class} = 'scrartcl';
             delete $parsed{opening}; # not needed for article.
         }
-    }
+
 
     unless ($parsed{notoc}) {
         if ($doc->wants_toc) {
